<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
	<xsl:template match="/">
		<html>
			<head>
				<title>Fate Core: <xsl:value-of select="/character/name/text()"/></title>
				<style type="text/css">
					/* Doing fonts as depicted below allows all browsers to enlarge or reduce fonts
					per the user's choice.*/
					body 
					{
					font-size:100%;  /* default font size is 16 pixels */
					font-family:Optima,sans-serif;
					} 
					p {font-size:0.75em;} /* default font size is 12 pixels */
					h2
					{
					text-align:center;
					font-size:1em;
					font-weight:bold;
					background-color:#99cc66;
					border-top-left-radius:10px;
					border-top-right-radius:10px;
					}
					div.title
					{
					text-align:center;
					font-weight:bold;
					background-color:#99cc66;
					border-top-left-radius:8px;
					border-top-right-radius:8px;
					}
					div.twocol
					{
					font-size:0.75em;
					border:2px solid;
					border-radius:10px;
					padding:10px;
					-webkit-column-count:2;
					-moz-column-count:2;
					column-count:2;
					-webkit-column-rule:thin;
					-moz-column-rule:thin;
					-webkit-column-rule-width:thin;
					-moz-column-rule-width:thin;
					column-rule-width:thin;
					-webkit-column-rule-style:solid;
					-moz-column-rule-style:solid;
					column-rule-style:solid;
					}
					div.right
					{
					background-color:#FFFFFF;
					float:right;
					width:50%;
					padding:3px;					
					}
					img.portrait
					{
					display:block;
					margin-left:auto;
					margin-right:auto;
					border:0px solid grey;
					border-radius:10px;
					white-space:nowrap;
					box-shadow: 0.2em 0.2em 1em;
					}
					#aspect
					{
					font-weight:bold;
					font-style:italic;
					}
				</style>
			</head>
			<body>
				<!-- ID -->
				<div class="twocol">
					<img class="portrait" src="portrait.png" alt="Portrait"/>
					
					<div class="title">ID<br/></div>
					<strong>Name: </strong>
					<xsl:value-of select="/character/name/text()"/><br/>
					<strong>Description: </strong>
					<xsl:value-of select="/character/datablock[@name='ID']/data[@name='Description']/text()"/><br/>
				
					<!-- Aspects -->
					<xsl:for-each select="/character/datablock[@name='Aspects']/data">
						<xsl:choose>
							<xsl:when test="@renamed != ''">
								<xsl:if test="@renamed != 'Aspect'">
									<!-- Output a title row on the first time through, only. -->
									<xsl:if test="position() = '1'"><div class="title">Aspects</div></xsl:if>
									<span id="aspect"><xsl:value-of select="@renamed"/></span>
									<xsl:if test="text() !=''">
										- <xsl:value-of select="text()"/>
									</xsl:if>
									<br/>
								</xsl:if>
							</xsl:when>
							<xsl:otherwise>
								<xsl:if test="text() != ''">
									<xsl:if test="position() = '1'"><div class="title">Aspects</div></xsl:if>
									<xsl:if test="text() !=''"><xsl:value-of select="text()"/></xsl:if>
									<br/>
								</xsl:if>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
					<br/>
					
					<!-- Stress -->
					<div class="title">Stress</div>
					Physical: 
					<xsl:choose>
						<xsl:when test="/character/datablock[@name='Stress']/data[@name='Physical Stress Taken']/text() != ''">
							<xsl:value-of select="translate( /character/datablock[@name='Stress']/data[@name='Physical Stress Taken']/text(), 'xo', '☒❑' )"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="/character/datablock[@name='Stress']/data[@name='Physical Stress']/text()"/> 
						</xsl:otherwise>
					</xsl:choose>
					
					<div class="right">
						<small>Enter "o" for each stress box you have. Use "x" in place of an o to mark off a stress box. Default is 2 stress boxes: oo.</small>
					</div>
					<br/>
					
					Mental: 
					<xsl:choose>
						<xsl:when test="/character/datablock[@name='Stress']/data[@name='Mental Stress Taken']/text() != ''">
							<xsl:value-of select="translate( /character/datablock[@name='Stress']/data[@name='Mental Stress Taken']/text(), 'xo', '☒❑' )"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="/character/datablock[@name='Stress']/data[@name='Mental Stress']/text()"/> 
						</xsl:otherwise>
					</xsl:choose>

					
					<br/>
					
					<xsl:if test="/character/datablock[@name='Stress']/data[@name='Extra Consequences']/text() !=''">
						Extra Consequences: <xsl:value-of select="/character/datablock[@name='Stress']/data[@name='Extra Consequences']/text()"/>
						<br/>
					</xsl:if>
					<br/>
					
					<!-- Consequences -->
					<div class="title">Consequences</div>
					<xsl:if test="/character/datablock[@name='Consequences']/data[@name='Mild']/text() !=''">
						<strong>Mild (-2): </strong>
						<xsl:value-of select="/character/datablock[@name='Consequences']/data[@name='Mild']/text()"/>
						<br/>
					</xsl:if>
					<xsl:if test="/character/datablock[@name='Consequences']/data[@name='Moderate']/text() != ''">
						<strong>Moderate (-4): </strong>
						<xsl:value-of select="/character/datablock[@name='Consequences']/data[@name='Moderate']/text()"/>
						<br/>
					</xsl:if>
					<xsl:if test="/character/datablock[@name='Consequences']/data[@name='Severe']/text() != ''">
						<strong>Severe (-6): </strong>
						<xsl:value-of select="/character/datablock[@name='Consequences']/data[@name='Severe']/text()"/>
						<br/>
					</xsl:if>
					<xsl:if test="/character/datablock[@name='Consequences']/data[@name='Extreme']/text() != ''">
						<strong>Extreme (-8): </strong>
						<xsl:value-of select="/character/datablock[@name='Consequences']/data[@name='Extreme']/text()"/>
						<br/>
					</xsl:if>
					<br/>

					<!-- Skills -->
					<div class="title">Skills</div>
					<xsl:if test="/character/datablock[@name='Skills']/data[@name='Legendary (+8)']/text() != ''">
						<strong>Legendary (+8): </strong>
						<xsl:value-of select="/character/datablock[@name='Skills']/data[@name='Legendary (+8)']/text()"/>
						<br/>
					</xsl:if>
					<xsl:if test="/character/datablock[@name='Skills']/data[@name='Epic (+7)']/text() != ''">
						<strong>Epic (+7): </strong>
						<xsl:value-of select="/character/datablock[@name='Skills']/data[@name='Epic (+7)']/text()"/>
						<br/>
					</xsl:if>
					<xsl:if test="/character/datablock[@name='Skills']/data[@name='Fantastic (+6)']/text() != ''">
						<strong>Fantastic (+6): </strong>
						<xsl:value-of select="/character/datablock[@name='Skills']/data[@name='Fantastic (+6)']/text()"/>
						<br/>
					</xsl:if>
					<xsl:if test="/character/datablock[@name='Skills']/data[@name='Superb (+5)']/text() != ''">
						<strong>Superb (+5): </strong>
						<xsl:value-of select="/character/datablock[@name='Skills']/data[@name='Superb (+5)']/text()"/>
						<br/>
					</xsl:if>
					<xsl:if test="/character/datablock[@name='Skills']/data[@name='Great (+4)']/text() != ''">
						<strong>Great (+4): </strong>
						<xsl:value-of select="/character/datablock[@name='Skills']/data[@name='Great (+4)']/text()"/>
						<br/>
					</xsl:if>
					<xsl:if test="/character/datablock[@name='Skills']/data[@name='Good (+3)']/text() != ''">
						<strong>Good (+3): </strong>
						<xsl:value-of select="/character/datablock[@name='Skills']/data[@name='Good (+3)']/text()"/>
						<br/>
					</xsl:if>
					<xsl:if test="/character/datablock[@name='Skills']/data[@name='Fair (+2)']/text() != ''">
						<strong>Fair (+2): </strong>
						<xsl:value-of select="/character/datablock[@name='Skills']/data[@name='Fair (+2)']/text()"/>
						<br/>
					</xsl:if>
					<xsl:if test="/character/datablock[@name='Skills']/data[@name='Average (+1)']/text() != ''">
						<strong>Average (+1): </strong>
						<xsl:value-of select="/character/datablock[@name='Skills']/data[@name='Average (+1)']/text()"/>
						<br/>
					</xsl:if>
					<br/>
							
					<!-- Stunts -->
					<xsl:for-each select="/character/datablock[@name='Stunts']/data">
						<!-- Stunts can be renamed by the user. -->
						<xsl:choose>
							<xsl:when test="@renamed != ''">
								<xsl:choose>
									<xsl:when test="text() != ''">
										<!-- Output a title row on the first time through, only. -->
										<xsl:if test="position() = '1'">
											<div class="title">Stunts</div>
										</xsl:if>
										<strong><xsl:value-of select="@renamed"/>. </strong>
										<xsl:value-of select="text()"/>
										<br/>
									</xsl:when>
									<xsl:otherwise>
										<xsl:if test="@renamed != 'Stunt'">
											<!-- Output a title row on the first time through, only. -->
											<xsl:if test="position() = '1'">
												<div class="title">Stunts</div>
											</xsl:if>
											<strong><xsl:value-of select="@renamed"/>. </strong>
											<xsl:value-of select="text()"/>
											<br/>
										</xsl:if>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:when>
							<xsl:otherwise>
								<xsl:if test="text() != ''">
									<!-- Output a title row on the first time through, only. -->
									<xsl:if test="position() = '1'">
										<div class="title">Stunts</div>
									</xsl:if>
									<xsl:value-of select="text()"/>
									<br/>
								</xsl:if>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
					<br/>
							
					<!-- Extras -->
					<xsl:for-each select="/character/datablock[@name='Extras']/data">
						<!-- Extras can be renamed by the user. -->
						<xsl:choose>
							<xsl:when test="@renamed != ''">
								<xsl:choose>
									<xsl:when test="text() != ''">
										<!-- Output a title row on the first time through, only. -->
										<xsl:if test="position() = '1'">
											<div class="title">Extras</div>
										</xsl:if>
										<strong><xsl:value-of select="@renamed"/>. </strong>
										<xsl:value-of select="text()"/>
										<br/>
									</xsl:when>
									<xsl:otherwise>
										<xsl:if test="@renamed !='Extra'">
											<!-- Output a title row on the first time through, only. -->
											<xsl:if test="position() = '1'">
												<div class="title">Extras</div>
											</xsl:if>
											<strong><xsl:value-of select="@renamed"/>. </strong>
											<xsl:value-of select="text()"/>
											<br/>
										</xsl:if>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:when>
							<xsl:otherwise>
								<xsl:if test="text() !=''">
									<!-- Output a title row on the first time through, only. -->
									<xsl:if test="position() = '1'">
										<div class="title">Extras</div>
										<br/>
									</xsl:if>
									<strong><xsl:value-of select="@name"/>. </strong>
									<xsl:value-of select="text()"/>
									<br/>
								</xsl:if>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
					<br/>
				</div>
				
				<!-- Include Journals, if available. -->
				<xsl:for-each select="//article">
					<p>
						<article>
							<xsl:attribute name="title">
								<xsl:value-of select="@title"/>
							</xsl:attribute>
							<h2><xsl:value-of select="@title"/></h2>
							<xsl:for-each select="span">
								<span>
									<xsl:attribute name="style">
										<xsl:value-of select="@style"/>
									</xsl:attribute>
									<xsl:value-of select="text()"/>
									<xsl:if test="br">
										<br/>
									</xsl:if>
								</span>
							</xsl:for-each>
						</article>	
					</p>
				</xsl:for-each>
			</body>
		</html>
	</xsl:template>
</xsl:stylesheet>
